@@ -25,7 +25,7 @@ class GSPeerConnectionWatcher:
             return frame
 
     @classmethod
-    async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None):
+    async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None, ontrackterminate=None):
         self = GSPeerConnectionWatcher()
         self.rtconfiList = []
         self.sio = socketio.AsyncClient()
@@ -34,14 +34,15 @@ class GSPeerConnectionWatcher:
         self.target = target
         self.onmessage = onmessage
         self.ontrack = ontrack
+        self.ontrackterminate = ontrackterminate
         self.logger = logging.getLogger(__name__)
 
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
         if self.gsdbs.credentials["turnenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
-                                            self.gsdbs.credentials["turnuser"],
-                                            self.gsdbs.credentials["turnpw"]))
+                                                 self.gsdbs.credentials["turnuser"],
+                                                 self.gsdbs.credentials["turnpw"]))
 
         @self.sio.event
         async def connect():
@@ -51,7 +52,6 @@ class GSPeerConnectionWatcher:
         async def joined():
             self.logger.info("joined")
 
-
         @self.sio.event
         async def broadcaster():
             if len(self.rtconfiList) > 0:
@@ -78,8 +78,7 @@ class GSPeerConnectionWatcher:
 
                 @track.on("ended")
                 async def on_ended():
-                    pass
-                    # await recorder.stop()
+                    self.ontrackterminate(self.gsdbs, self.target)
 
             await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
             await self.sio.emit("watcher",
